capture log close
log using sim_run.smcl , s replace
* Run data simulation programs based on gendata.ado
* (should be in adopath)

* set the seed, once and once only, before setting anything else up
set seed 7343

tempname posty
postfile `posty' double(beta se df) byte(stages nstudies inbeta) int id using estimates-2s, replace

timer on 1
quietly {
noi _dots 0, title("Simulation running...")
forvalues s = 1/1000 {
	noi _dots `s' 0
	foreach i of numlist 2/40 {
		clear
		quietly gendata , nstudies(`i') nmean(3.798) nsd(1.104) randprop(.5) tau(1) beta(0) sigma(1)
			quietly replace trt = trt - 0.5
		* one-stage - in Stata this is slow and prone to stalling so run in sas -proc mixed- instead
		//mixed y trt i.study || study: trt, nocons reml dfmethod(kr)
		/* -post `posty'- removed for -mixed- as above line is farmed out to sas proc mixed for speed */
		* two-stage
		quietly ipdmetan, nograph nohet study(study) re(kr): regress y trt if study <=`i'
		post `posty' (`r(eff)') (`r(se_eff)') (`r(df_kr)') (2) (`i') (0) (`s')
		export delimited raw\datai`i's`s' , delimiter(",") replace
	}
}
}
postclose` posty'
timer off 1
timer list

log close


* Analysis of estimates datasets
use estimates-1s, clear // from simcont-prean.do
append using estimates-2s
	lab def stages 1 "1s" 2 "2s"
	lab val stages stages

simsum beta , max(200) saving(simsum_results, replace) ///
	true(inbeta) methodvar(stages) id(id) se(se) df(df) by(nstudies) mcse

/* plot of distribution of study sizes
clear *
set obs 100000
qui gen int n = exp(rnormal(3.798,1.104)) // size of study, following Rucker et al.
	qui replace n = 20 if n < 20

spikeplot n, fraction round(10) ylab(, format(%3.2f))
*/
